@@ -1,12 +1,13 @@
 import time
 import pymysql
+import sqlite3
 
 mysql = 'mysql'
-
+sqlite = 'sqlite'
 
 ENGINE_DICT = {
     'mysql':pymysql,
-
+    'sqlite':sqlite3
 }
 
 class Base(object):
@@ -35,7 +36,8 @@ class Base(object):
     def connect_db(self):
         try:
             self.db = self.connect()
-            self._load_tables()
+            if self._engine != sqlite:
+                self._load_tables()
             # print('数据库模块连接成功')
             print('connect success!')
             # IntervalTask(30, self.keep_connect)
@@ -49,9 +51,9 @@ class Base(object):
         if self._engine == mysql:
             self.db = self.db_engine.connect(self._host, self._user, self._psw, self._dbname, charset='utf8')
             return self.db
-        # if self._engine == sqlite:
-        #     self.db = self.db_engine.connect(self._dbname)
-        #     return self.db
+        if self._engine == sqlite:
+            self.db = self.db_engine.connect(self._dbname)
+            return self.db
 
 
     def become_busy(self):
@@ -71,19 +73,28 @@ class Base(object):
     def keep_connect(self):
         if self.db is None:
             self.connect_db()
-        self.query('select 1')
+        if self._engine != sqlite:
+            self.query('select 1')
 
 
 
     def load_an_table(self, table):
-        sql = 'show fields from ' + table
-        res = self.query(sql, show_sql=False)
-        if res is None:
-            return
-        column_list = list(map(lambda x: x[0], res))
-        if 'signal' in column_list:
-            column_list.remove('signal')
-        self._tables[table] = column_list
+        if self._engine == sqlite:
+            sql = 'PRAGMA table_info(%s)'%table
+            res = self.query(sql, show_sql=False)
+            if res is None:
+                return
+            column_list = list(map(lambda x: x[1], res))
+            self._tables[table] = column_list
+        else:
+            sql = 'show fields from ' + table
+            res = self.query(sql, show_sql=False)
+            if res is None:
+                return
+            column_list = list(map(lambda x: x[0], res))
+            if 'signal' in column_list:
+                column_list.remove('signal')
+            self._tables[table] = column_list
         return column_list
 
     # 加载所有数据库表名
@@ -102,8 +113,11 @@ class Base(object):
         sql = 'create table %s(' % table
 
         tail = ''
+
         for item in colums:
             col = ''
+            if self._engine == sqlite:
+                item= item[:-1]
             for i in item:
                 col += str(i)
                 col += ' '
@@ -112,7 +126,11 @@ class Base(object):
 
         tail = tail[:-1] + ')'
         sql += tail
-        sql += '%s charset=utf8,comment="%s"'%('engine=innodb,' if self._engine==mysql else '',table_comment)
+        # sql += 'charset=utf8mb4'
+        if self._engine == mysql:
+            sql += 'charset=utf8mb4,engine=innodb,comment="%s"'%(table_comment)
+        if self._engine == sqlite:
+            sql = sql.replace('int AUTO_INCREMENT primary key','INTEGER PRIMARY KEY AUTOINCREMENT')
         self.query(sql, show_sql)
         self.db.commit()
         return
@@ -146,7 +164,7 @@ class Base(object):
         return sql
 
     @staticmethod
-    def bind_conditions(sql, conditions, or_cond):
+    def bind_conditions(sql, conditions, or_cond,unique = True):
         # print(sql)
         if conditions is None:
             conditions = []
@@ -160,7 +178,10 @@ class Base(object):
                 value = unit[2]
                 if type("") == type(value):
                     value = "'%s'" % value
-                sql = sql + "binary %s %s %s " % (unit[0], unit[1], value) + "  and "
+                if 'id' not in unit[0]:
+                    sql = sql + "binary %s %s %s " % (unit[0], unit[1], value) + "  and "
+                else:
+                    sql = sql + " %s %s %s " % (unit[0], unit[1], value) + "  and "
             sql = sql[:-4]
             if len(or_cond) > 0:
                 sql += ' or '
@@ -170,9 +191,15 @@ class Base(object):
                 value = unit[2]
                 if type("") == type(value):
                     value = "'%s'" % value
-                sql = sql + "binary %s %s %s " % (unit[0], unit[1], value) + ' or '
+                if 'id' not in unit[0]:
+                    sql = sql + "binary %s %s %s " % (unit[0], unit[1], value) + ' or '
+                else:
+                    sql = sql + " %s %s %s " % (unit[0], unit[1], value) + ' or '
             sql = sql[:-3]
 
+        if unique == False:
+            sql = sql.replace('binary', '')
+
         return sql
 
     # 查找数据（单条）
@@ -248,7 +275,9 @@ class Base(object):
         return
 
     def update(self, table, conditions, or_cond, params, isCommit=True, show_sql=False):
+        # print('开始执行')
         if params == {} or params is None:
+            # print('没有params，结束执行')
             return
         sql = 'update %s set ' % table
         for param, value in params.items():
@@ -258,13 +287,17 @@ class Base(object):
 
         sql = sql[:-1] + ' where  '
         sql = Base.bind_conditions(sql, conditions, or_cond)
+        # print(sql)
 
         self.query(sql, show_sql)
+        # print('是否自动提交', isCommit)
         if isCommit is True:
+            # print('自动提交')
             self.db.commit()
+            # print('自动提交完毕')
         return
 
-    def delete(self, table, condition, or_cond, is_commit, show_sql=False):
+    def delete(self, table, condition, or_cond, is_commit=True, show_sql=False):
         sql = 'delete from %s where  ' % table
         sql = Base.bind_conditions(sql, condition, or_cond)
         #  #
@@ -274,16 +307,19 @@ class Base(object):
         return
 
     def query(self, sql, show_sql=False):
+        if self._engine == sqlite:
+            sql = sql.replace('binary','')
         self.executing_query = sql
         if sql == 'select 1':
             show_sql = False
         if show_sql is True:
             print(sql)
-        try:
-            self.db.ping(reconnect=True)
-        except Exception as e:
-            print(sql, 'db error', str(e), 'reconnecting...')
-            self.connect()
+        if self._engine != sqlite:
+            try:
+                self.db.ping(reconnect=True)
+            except Exception as e:
+                print(sql, 'db error', str(e), 'reconnecting...')
+                self.connect()
         cursor = self.db.cursor()
         try:
             # res = time.time()
@@ -301,6 +337,7 @@ class Base(object):
 
         self.update_last_connect_time()
         self.executing_query = ''
+        # print(results)
         # print(sql,'执行时间',time.time()-res)
         return results
         # results = cursor.fetchall()
@@ -317,7 +354,12 @@ class Base(object):
         return self.last_connect_time
 
     def query_one(self, sql):
-        self.db.ping(reconnect=True)
+        if self._engine != sqlite:
+            try:
+                self.db.ping(reconnect=True)
+            except Exception as e:
+                print(sql, 'db error', str(e), 'reconnecting...')
+                self.connect()
         # cur.execute(sql)
         # db.commit()
         cursor = self.db.cursor()
