@@ -1,4 +1,4 @@
 from .server import Data as db
 
-class Data(db):
+class Ring(db):
     pass
\ No newline at end of file
