@@ -92,14 +92,14 @@ class Data(object):
         return data
 
     @staticmethod
-    def find(table, conditions, or_cond=None, fields=('*',), order=None, show_sql=False,base_id='default',show_manager_id=False):
+    def find(table, conditions, fields=('*',), or_cond=None, order=None, show_sql=False,base_id='default',show_manager_id=False):
         if show_manager_id is True:
             print('本次任务通过',base_id,'执行')
 
         return Data.Base_pool[base_id].find(table, conditions, or_cond, fields, order, show_sql) if base_id in Data.Base_pool else None
 
     @staticmethod
-    def select(table, conditions, or_cond=None, fields=('*',), group=None, order=None, limit=None, show_sql=False,base_id='default',show_manager_id=False):
+    def select(table, conditions, fields=('*',),or_cond=None, group=None, order=None, limit=None, show_sql=False,base_id='default',show_manager_id=False):
         if show_manager_id is True:
             print('本次任务通过',base_id,'执行')
         return Data.Base_pool[base_id].select(table, conditions, or_cond, fields, group, order, limit, show_sql) if base_id in Data.Base_pool else None
@@ -149,7 +149,7 @@ class Data(object):
         res = {}
         all_data = Data.select(table,[])
         for i in all_data:
-            res[i['id']] = 1
+            res[i['id']] = i
         return res
 
     @staticmethod
